Documentation
¶
Index ¶
- Constants
- func IsPduSessionIdInPsiRange(id int32) bool
- func IsValidGpsi(gpsi string) bool
- func IsValidPduSessionID(pduSessionID string) bool
- func IsValidPei(pei string) bool
- func IsValidPlmnId(plmnId string) bool
- func IsValidSnssai(snssai string) bool
- func IsValidSuci(suci string) bool
- func IsValidSupi(supi string) bool
- func ValidateGroupIdFormat(groupId string) error
Constants ¶
const ( PeiTypeImei = "IMEI" PeiTypeImeisv = "IMEISV" PeiTypeUnknown = "UNKNOWN" )
PEI types
Variables ¶
This section is empty.
Functions ¶
func IsPduSessionIdInPsiRange ¶
TS 24.501 9.11.3.57 (PSI 0-15)
func IsValidGpsi ¶
IsValidGpsi valid GPSI format (TS 29.571 5.3.2)
func IsValidPduSessionID ¶
TS 29.571 5.4.2 valid PDU Session ID is an integer in the range 0 to 255
func IsValidPei ¶
IsValidPei checks if the string is a valid PEI (IMEI or IMEISV)
func IsValidPlmnId ¶
IsValidPlmnId checks if the string is a valid PLMN ID (MCC+MNC) Format: 5 or 6 digits
func IsValidSnssai ¶
IsValidSnssai checks if the string is a valid S-NSSAI Format: SST (e.g. "1") or SST-SD (e.g. "1-000001")
func IsValidSupi ¶
IsValidSupi checks if the given SUPI is valid according to 3GPP specifications
func ValidateGroupIdFormat ¶
ValidateGroupIdFormat validates the external group identity format Expected pattern: prefix-mcc(3 digits)-mnc(2-3 digits)-localGroupId
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.